From ab7a5eb9af0b04c8257883b0acf43e376aea66cb Mon Sep 17 00:00:00 2001
From: Julien Lancelot <julien.lancelot@sonarsource.com>
Date: Thu, 4 Feb 2016 14:46:05 +0100
Subject: SONAR-7242 Update default background color

---
 .../src/main/java/org/sonar/api/server/authentication/Display.java    | 4 ++--
 .../test/java/org/sonar/api/server/authentication/DisplayTest.java    | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/sonar-plugin-api/src/test/java/org/sonar/api/server/authentication/DisplayTest.java b/sonar-plugin-api/src/test/java/org/sonar/api/server/authentication/DisplayTest.java
index 2b756383238..b11b8946bb8 100644
--- a/sonar-plugin-api/src/test/java/org/sonar/api/server/authentication/DisplayTest.java
+++ b/sonar-plugin-api/src/test/java/org/sonar/api/server/authentication/DisplayTest.java
@@ -42,12 +42,12 @@ public class DisplayTest {
   }
 
   @Test
-  public void create_display_woth_default_background_color() throws Exception {
+  public void create_display_with_default_background_color() throws Exception {
     Display display = Display.builder()
       .setIconPath("/static/authgithub/github.svg")
       .build();
 
-    assertThat(display.getBackgroundColor()).isEqualTo("#000000");
+    assertThat(display.getBackgroundColor()).isEqualTo("#236a97");
   }
 
   @Test
diff --git a/sonar-plugin-api/src/main/java/org/sonar/api/server/authentication/Display.java b/sonar-plugin-api/src/main/java/org/sonar/api/server/authentication/Display.java
index 74ffc57ad6a..6931e723169 100644
--- a/sonar-plugin-api/src/main/java/org/sonar/api/server/authentication/Display.java
+++ b/sonar-plugin-api/src/main/java/org/sonar/api/server/authentication/Display.java
@@ -58,7 +58,7 @@ public final class Display {
    * Background color for the provider button displayed in the login form.
    * It's a Hexadecimal value, for instance #205081.
    * <p/>
    * If not provided, the default value is black (#000000)
    */
   public String getBackgroundColor() {
     return backgroundColor;
@@ -71,7 +71,7 @@ public final class Display {
   public static class Builder {
 
     private String iconPath;
-    private String backgroundColor = "#000000";
+    private String backgroundColor = "#236a97";
 
     private Builder() {
     }
@@ -58,7 +58,7 @@ public final class Display {
    * It's a Hexadecimal value, for instance #205081.
    * <p/>
-   * If not provided, the default value is black (#000000)
+   * If not provided, the default value is #236a97
    */
   public String getBackgroundColor() {
-- 
cgit v1.2.3